#!/bin/sh
exe_name=$0
exe_dir=`dirname "$0"`
if [ $# -lt "16" ]; then
echo "----------------------------------------------------------------------------------------------"
echo "Usage: 
./run_hallucination_v12.sh atlasvollist subjectvollist isskull NumAtlasPatches NumSubjectPatches 
NumNearestNeighbors PatchSize NumCPU OutlierLevel InputModality OutputModality 
AtlasStartSlice SubjectStartSlice AtlasWMPeaks SubjectWMPeaks outputvolname 
Input and outvolume name should be either NIFTI or XML
atlasvollist          Comma separated atlas volumes, e.g. to synthesize CT from two UTE images, 
                      use atlasUTE1.nii,atlasUTE2.nii,atlasCT.nii
subjectvollist        Comma separated subject volumes, e.g. subjectUTE1.nii,subjectUTE2.nii 
                      (number of subject volumes = number of atlas volumes - 1)
isskull               If the UTE images contain skull. Enter yes or no. If the images contain
                      skull, then AtlasWMPeaks/SubjectWMPeaks (defined later) must be mentioned,
                      because white matter peak-finding algorithm usually does not work on images
                      with skull.
NumAtlasPatches       Number of atlas patches used to generated atlas patch cloud. A typical 
                      number is between 2E4 to 1E5. 
NumSubjectPatches     Number of subject patches used to generated subject patch cloud. 
                      A typical number is between 2E4 to 1E5. Usually, NumSubjectPatches>2*NumAtlasPatches
NumNearestNeighbors   Number of nearest atlas patches to be searched for each subject patch. 
                      A typical number is 10 to 25.
PatchSize             Either 3x3x1 or 3x3x3
NumCPU                For multi-core processors, use available number of CPUs (maximum 12).			 
Outlierlevel          To remove outliers, either low, medium, high, or none (default)
InputModality         Options are SPGR,MPRAGE,T2 or CT. For multichannel input, use the 
                      modality of first channel. For UTE images, use SPGR.
OutputModality        Options are SPGR,MPRAGE,T2 or CT
AtlasStartSlice       Atlas slices where the patches are collected from. 0-->Default. 
                      Usually choose slices from the middle of the atlas image
SubjectStartSlice     Subject slices where the patches are collected from. 0-->Default. 
                      Usually choose slices from the middle of the subject image
AtlasWMPeaks          For images with skull, enter WM peaks in comma separated format, 
                      e.g. 199.0,299.0. For images without skull, enter zero for default, 
                      where WM peak is found using a kernel density estimator. Mixing 0 and
                      non-zero peaks are allowed, e.g., xx,0,yy,0 --> first and third image
                      will be scaled with xx and yy, while second and fourth image will be
                      scaled by default WM peak. 
                      Length(AtlasWMPeaks) = number of atlas volumes - 1.
SubjectWMPeaks        For images with skull, enter WM peaks in comma separated format, 
                      e.g. 199.0,299.0
                      Length(SubjectWMPeaks) = number of subject volumes.
outputvolname         Full path and name of the output volume. Either XML or NIFTI

----------------------------------------------------------------------------------------------"
  exit 1
else
  ATLAS=$1  
  SUBJECT=$2
  SKULL=$3
  NUMATLAS=$4
  NUMSUBJECT=$5
  NUMNN=$6
  PSIZE=$7
  NUMCPU=$8
  OUTLIER=$9
  INPUTMODAL=${10}
  OUTPUTMODAL=${11}
  ATLASSLICE=${12}
  SUBJECTSLICE=${13}
  ATLASWMPEAK=${14}
  SUBJECTWMPEAK=${15}
  OUTVOL=${16}
  MCRROOT=${17}
  if [ "$MCRROOT"x == "x" ]; then
    echo "Using default MCRROOT"
    export MCRROOT=/usr/local/Matlab_Runtime_R2013a/v81
    if [ ! -d "$MCRROOT" ]; then
        echo "MCRROOT not found. Exiting."
        exit 1
    fi
  fi
   
  
      echo "Setting up environment variables"
      echo "MCR ROOT is $MCRROOT"
      LD_LIBRARY_PATH=.:${MCRROOT}/runtime/glnxa64 ;
      LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/bin/glnxa64 ;
      LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/sys/os/glnxa64;
      MCRJRE=${MCRROOT}/sys/java/jre/glnxa64/jre/lib/amd64 ;
      LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/native_threads ; 
	  	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/server ;
      LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/client ;
	  	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE} ;  
      XAPPLRESDIR=${MCRROOT}/X11/app-defaults ;
      export LD_LIBRARY_PATH;
      export XAPPLRESDIR;
      #echo LD_LIBRARY_PATH is ${LD_LIBRARY_PATH};
      shift 1
      args=
      #while [ $# -gt 0 ]; do
      #    token=`$1" | sed 's/ /\\\\ /g'`   # Add blackslash before each blank
      #    args="${args} ${token}" 
      #    shift
      #done
      echo "Atlas volume: $ATLAS"
      echo "Subject volume: $SUBJECT"
      echo "${exe_dir}"/run_hallucination_v12 $ATLAS $SUBJECT $SKULL $NUMATLAS $NUMSUBJECT $NUMNN $PSIZE $NUMCPU $OUTLIER $INPUTMODAL $OUTPUTMODAL $ATLASSLICE $SUBJECTSLICE $ATLASWMPEAK $SUBJECTWMPEAK $OUTVOL 
      "${exe_dir}"/run_hallucination_v12  $ATLAS $SUBJECT $SKULL $NUMATLAS $NUMSUBJECT $NUMNN $PSIZE $NUMCPU $OUTLIER $INPUTMODAL $OUTPUTMODAL $ATLASSLICE $SUBJECTSLICE $ATLASWMPEAK $SUBJECTWMPEAK $OUTVOL 
   
fi
